==> aria2_1.21.0.orig.tar.gz: aria2-1.21.0/src/TorrentAttribute.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_TORRENT_ATTRIBUTE_H
#define D_TORRENT_ATTRIBUTE_H

#include "ContextAttribute.h"

#include <string>
#include <vector>

#include <aria2/aria2.h>
#include "a2time.h"

namespace aria2 {

struct TorrentAttribute : public ContextAttribute {
  std::string name;
  BtFileMode mode;
  std::vector<std::vector<std::string>> announceList;
  std::vector<std::pair<std::string, uint16_t>> nodes;
  // raw hash value 20 bytes.
  std::string infoHash;
  std::string metadata;
  size_t metadataSize;
  bool privateTorrent;
  time_t creationDate;
  std::string comment;
  std::string createdBy;
  std::vector<std::string> urlList;

  TorrentAttribute();
  ~TorrentAttribute();

  // Don't allow copying
  TorrentAttribute(const TorrentAttribute&);
  TorrentAttribute& operator=(const TorrentAttribute&);
};

} // namespace aria2

#endif // D_TORRENT_ATTRIBUTE_H

==> aria2_1.35.0.orig.tar.gz: aria2-1.35.0/src/TorrentAttribute.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2010 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_TORRENT_ATTRIBUTE_H
#define D_TORRENT_ATTRIBUTE_H

#include "ContextAttribute.h"

#include <string>
#include <vector>

#include <aria2/aria2.h>
#include "a2time.h"

namespace aria2 {

struct TorrentAttribute : public ContextAttribute {
  std::string name;
  BtFileMode mode;
  std::vector<std::vector<std::string>> announceList;
  std::vector<std::pair<std::string, uint16_t>> nodes;
  // raw hash value 20 bytes.
  std::string infoHash;
  std::string metadata;
  size_t metadataSize;
  bool privateTorrent;
  time_t creationDate;
  std::string comment;
  std::string createdBy;
  std::vector<std::string> urlList;

  TorrentAttribute();
  ~TorrentAttribute();

  // Don't allow copying
  TorrentAttribute(const TorrentAttribute&) = delete;
  TorrentAttribute& operator=(const TorrentAttribute&) = delete;
};

} // namespace aria2

#endif // D_TORRENT_ATTRIBUTE_H
